@@ -3,7 +3,7 @@
 #include "detection/gtk_qt/gtk_qt.h"
 #include "detection/displayserver/displayserver.h"
 
-const char* ffDetectIcons(FFstrbuf* result)
+const char* ffDetectIcons(FFIconsResult* result)
 {
     const FFDisplayServerResult* wmde = ffConnectDisplayServer();
 
@@ -18,18 +18,13 @@ const char* ffDetectIcons(FFstrbuf* result)
     if(plasma->length == 0 && gtk2->length == 0 && gtk3->length == 0 && gtk4->length == 0)
         return "No icons could be found";
 
-    FF_STRBUF_AUTO_DESTROY gtkPretty = ffStrbufCreate();
-    ffParseGTK(&gtkPretty, gtk2, gtk3, gtk4);
+    ffParseGTK(&result->icons2, gtk2, gtk3, gtk4);
 
     if(plasma->length > 0)
     {
-        ffStrbufAppend(result, plasma);
-        ffStrbufAppendS(result, " [QT]");
-
-        if(gtkPretty.length > 0)
-            ffStrbufAppendS(result, ", ");
+        ffStrbufAppend(&result->icons1, plasma);
+        ffStrbufAppendS(&result->icons1, " [QT]");
     }
-    ffStrbufAppend(result, &gtkPretty);
 
     return NULL;
 }
