@@ -12,6 +12,7 @@
 #include "modules/camera/option.h"
 #include "modules/chassis/option.h"
 #include "modules/cpu/option.h"
+#include "modules/cpucache/option.h"
 #include "modules/cpuusage/option.h"
 #include "modules/colors/option.h"
 #include "modules/cursor/option.h"
@@ -22,6 +23,7 @@
 #include "modules/disk/option.h"
 #include "modules/diskio/option.h"
 #include "modules/display/option.h"
+#include "modules/dns/option.h"
 #include "modules/editor/option.h"
 #include "modules/font/option.h"
 #include "modules/host/option.h"
