@@ -51,6 +51,9 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
                 const char* colorOutput = yyjson_get_str(yyjson_obj_get(val, "output"));
                 if (colorOutput)
                     ffOptionParseColor(colorOutput, &options->colorOutput);
+                const char* colorSeparator = yyjson_get_str(yyjson_obj_get(val, "separator"));
+                if (colorSeparator)
+                    ffOptionParseColor(colorSeparator, &options->colorSeparator);
             }
             else
                 return "display.color must be either a string or an object";
@@ -177,9 +180,13 @@ const char* ffOptionsParseDisplayJsonConfig(FFOptionsDisplay* options, yyjson_va
                 if (charTotal)
                     ffStrbufSetS(&options->barCharTotal, charTotal);
 
-                yyjson_val* border = yyjson_obj_get(val, "border");
-                if (border)
-                    options->barBorder = yyjson_get_bool(border);
+                yyjson_val* borderLeft = yyjson_obj_get(val, "borderLeft");
+                if (borderLeft)
+                    ffStrbufSetS(&options->barBorderLeft, yyjson_get_str(borderLeft));
+
+                yyjson_val* borderRight = yyjson_obj_get(val, "borderRight");
+                if (borderRight)
+                    ffStrbufSetS(&options->barBorderRight, yyjson_get_str(borderRight));
 
                 yyjson_val* width = yyjson_obj_get(val, "width");
                 if (width)
@@ -252,6 +259,11 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
             optionCheckString(key, value, &options->colorOutput);
             ffOptionParseColor(value, &options->colorOutput);
         }
+        else if(ffStrEqualsIgnCase(subkey, "separator"))
+        {
+            optionCheckString(key, value, &options->colorSeparator);
+            ffOptionParseColor(value, &options->colorSeparator);
+        }
         else
             return false;
     }
@@ -338,8 +350,10 @@ bool ffOptionsParseDisplayCommandLine(FFOptionsDisplay* options, const char* key
             ffOptionParseString(key, value, &options->barCharTotal);
         else if(ffStrEqualsIgnCase(subkey, "width"))
             options->barWidth = (uint8_t) ffOptionParseUInt32(key, value);
-        else if(ffStrEqualsIgnCase(subkey, "border"))
-            options->barBorder = ffOptionParseBoolean(value);
+        else if(ffStrEqualsIgnCase(subkey, "border-left"))
+            ffOptionParseString(key, value, &options->barBorderLeft);
+        else if(ffStrEqualsIgnCase(subkey, "border-right"))
+            ffOptionParseString(key, value, &options->barBorderRight);
         else
             return false;
     }
@@ -355,7 +369,8 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     ffStrbufInit(&options->colorKeys);
     ffStrbufInit(&options->colorTitle);
     ffStrbufInit(&options->colorOutput);
-    options->brightColor = true;
+    ffStrbufInit(&options->colorSeparator);
+    options->brightColor = !instance.state.terminalLightTheme;
     ffStrbufInitStatic(&options->keyValueSeparator, ": ");
 
     options->showErrors = false;
@@ -378,18 +393,19 @@ void ffOptionsInitDisplay(FFOptionsDisplay* options)
     options->tempUnit = FF_TEMPERATURE_UNIT_CELSIUS;
     options->tempNdigits = 1;
     ffStrbufInitStatic(&options->tempColorGreen, FF_COLOR_FG_GREEN);
-    ffStrbufInitStatic(&options->tempColorYellow, FF_COLOR_FG_LIGHT_YELLOW);
-    ffStrbufInitStatic(&options->tempColorRed, FF_COLOR_FG_LIGHT_RED);
+    ffStrbufInitStatic(&options->tempColorYellow, instance.state.terminalLightTheme ? FF_COLOR_FG_YELLOW : FF_COLOR_FG_LIGHT_YELLOW);
+    ffStrbufInitStatic(&options->tempColorRed, instance.state.terminalLightTheme ? FF_COLOR_FG_RED : FF_COLOR_FG_LIGHT_RED);
 
     ffStrbufInitStatic(&options->barCharElapsed, "■");
     ffStrbufInitStatic(&options->barCharTotal, "-");
+    ffStrbufInitStatic(&options->barBorderLeft, "[ ");
+    ffStrbufInitStatic(&options->barBorderRight, " ]");
     options->barWidth = 10;
-    options->barBorder = true;
     options->percentType = 9;
     options->percentNdigits = 0;
     ffStrbufInitStatic(&options->percentColorGreen, FF_COLOR_FG_GREEN);
-    ffStrbufInitStatic(&options->percentColorYellow, FF_COLOR_FG_LIGHT_YELLOW);
-    ffStrbufInitStatic(&options->percentColorRed, FF_COLOR_FG_LIGHT_RED);
+    ffStrbufInitStatic(&options->percentColorYellow, instance.state.terminalLightTheme ? FF_COLOR_FG_YELLOW : FF_COLOR_FG_LIGHT_YELLOW);
+    ffStrbufInitStatic(&options->percentColorRed, instance.state.terminalLightTheme ? FF_COLOR_FG_RED : FF_COLOR_FG_LIGHT_RED);
 
     options->tsVersion = true;
 }
@@ -399,6 +415,7 @@ void ffOptionsDestroyDisplay(FFOptionsDisplay* options)
     ffStrbufDestroy(&options->colorKeys);
     ffStrbufDestroy(&options->colorTitle);
     ffStrbufDestroy(&options->colorOutput);
+    ffStrbufDestroy(&options->colorSeparator);
     ffStrbufDestroy(&options->keyValueSeparator);
     ffStrbufDestroy(&options->barCharElapsed);
     ffStrbufDestroy(&options->barCharTotal);
@@ -435,6 +452,10 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
             yyjson_mut_obj_add_strbuf(doc, color, "keys", &options->colorKeys);
         if (!ffStrbufEqual(&options->colorTitle, &defaultOptions.colorTitle))
             yyjson_mut_obj_add_strbuf(doc, color, "title", &options->colorTitle);
+        if (!ffStrbufEqual(&options->colorOutput, &defaultOptions.colorOutput))
+            yyjson_mut_obj_add_strbuf(doc, color, "output", &options->colorOutput);
+        if (!ffStrbufEqual(&options->colorSeparator, &defaultOptions.colorSeparator))
+            yyjson_mut_obj_add_strbuf(doc, color, "separator", &options->colorSeparator);
         if (yyjson_mut_obj_size(color) > 0)
         {
             if (yyjson_mut_obj_size(color) == 2 && ffStrbufEqual(&options->colorKeys, &options->colorTitle))
@@ -547,8 +568,10 @@ void ffOptionsGenerateDisplayJsonConfig(FFOptionsDisplay* options, yyjson_mut_do
             yyjson_mut_obj_add_strbuf(doc, bar, "charElapsed", &options->barCharElapsed);
         if (!ffStrbufEqual(&options->barCharTotal, &defaultOptions.barCharTotal))
             yyjson_mut_obj_add_strbuf(doc, bar, "charTotal", &options->barCharTotal);
-        if (options->barBorder != defaultOptions.barBorder)
-            yyjson_mut_obj_add_bool(doc, bar, "border", options->barBorder);
+        if (!ffStrbufEqual(&options->barBorderLeft, &defaultOptions.barBorderLeft))
+            yyjson_mut_obj_add_strbuf(doc, bar, "borderLeft", &options->barBorderLeft);
+        if (!ffStrbufEqual(&options->barBorderRight, &defaultOptions.barBorderRight))
+            yyjson_mut_obj_add_strbuf(doc, bar, "borderRight", &options->barBorderRight);
         if (options->barWidth != defaultOptions.barWidth)
             yyjson_mut_obj_add_uint(doc, bar, "width", options->barWidth);
 
